==> xmule-1.8.1.tar.bz2: xmule-1.8.1/src/ColorFrameCtrl.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

// ColorFrameCtrl.h : header file
//

#ifndef __ColorFrameCtrl_H__
#define __ColorFrameCtrl_H__

#include <wx/brush.h>
#ifndef RGB
#define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
#endif

/////////////////////////////////////////////////////////////////////////////
// CColorFrameCtrl window

#include <wx/control.h>

class CColorFrameCtrl : public wxControl
{
// Construction
public:
	CColorFrameCtrl( wxWindow* parent, int id,int wid,int hei );

// Attributes
public:
	void SetFrameColor(COLORREF color);
	void SetBackgroundColor(COLORREF color);

	// Operations
public:

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CColorFrameCtrl)
	public:
	//virtual BOOL Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID=NULL);
	//}}AFX_VIRTUAL

// Implementation
public:
	COLORREF m_crBackColor;        // background color
	COLORREF m_crFrameColor;       // frame color

	virtual ~CColorFrameCtrl();

	// Generated message map functions
protected:
	//{{AFX_MSG(CColorFrameCtrl)
	//afx_msg void OnPaint();
	void OnPaint(wxPaintEvent& evt);
	void OnSize(wxSizeEvent& evt);
	//ax_msg void OnSize(UINT nType, int cx, int cy); 
	//}}AFX_MSG
	//DECLARE_MESSAGE_MAP()
	DECLARE_EVENT_TABLE()

	  //CRect  m_rectClient;
	  //CBrush m_brushBack;
	  //CBrush m_brushFrame;
	  RECT m_rectClient;
	wxBrush m_brushBack,m_brushFrame;
};

/////////////////////////////////////////////////////////////////////////////
#endif

==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/ColorFrameCtrl.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef __ColorFrameCtrl_H__
#define __ColorFrameCtrl_H__

#include <wx/brush.h>                   // Needed for wxControl
#include <wx/control.h>                 // Needed for wxControl

#include "wintypes.h"                   // Needed for COLORREF

#ifndef RGB
#define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
#endif

class CColorFrameCtrl : public wxControl
{
// Construction
public:
	CColorFrameCtrl( wxWindow* parent, int id,int wid,int hei );

// Attributes
public:
	void SetFrameColor(COLORREF color);
	void SetBackgroundColor(COLORREF color);

	// Operations
public:

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CColorFrameCtrl)
	public:
	//virtual BOOL Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID=NULL);
	//}}AFX_VIRTUAL

// Implementation
public:
	COLORREF m_crBackColor;        // background color
	COLORREF m_crFrameColor;       // frame color

	virtual ~CColorFrameCtrl();

	// Generated message map functions
protected:
	//{{AFX_MSG(CColorFrameCtrl)
	//afx_msg void OnPaint();
	void OnPaint(wxPaintEvent& evt);
	void OnSize(wxSizeEvent& evt);
	//ax_msg void OnSize(UINT nType, int cx, int cy); 
	//}}AFX_MSG
	//DECLARE_MESSAGE_MAP()
	DECLARE_EVENT_TABLE()

	  //CRect  m_rectClient;
	  //CBrush m_brushBack;
	  //CBrush m_brushFrame;
	  RECT m_rectClient;
	wxBrush m_brushBack,m_brushFrame;
};

/////////////////////////////////////////////////////////////////////////////
#endif
